@@ -47,7 +47,7 @@ def load_dataset(path_metadata_file: str,
     :return: (*Dataset*) A dataset object.
     """
 
-    ext_img = '.' + ext_img
+    _ext_img = '.' + ext_img
     metadata_file = pandas.read_excel(path_metadata_file)
     metadata = numpy.array(metadata_file)
     names_feats = [metadata_file.columns.values[idx_img_id]]
@@ -61,10 +61,7 @@ def load_dataset(path_metadata_file: str,
 
     # Read images in the dataset.
     for i in iter_range:
-        img = get_image_data(path_imgs + '/' + metadata[i, idx_img_id] + ext_img)
-
-        # Swap axes the loaded image to fit the data format into the torchvision library.
-        # img = torch.swapaxes(img, 0, 2)
+        img = get_image_data(path_imgs + '/' + metadata[i, idx_img_id] + _ext_img)
 
         if idx_target is None:
             list_data.append(Data(x=img, idx=i, dtype=DTYPE_IMG))
