@@ -179,7 +179,10 @@ class GNN(PyTorchModel):
             if isinstance(x, Batch):
                 batch = x.batch
             else:
-                batch = torch.zeros(h.shape[0], dtype=torch.long).cuda()
+                batch = torch.zeros(h.shape[0], dtype=torch.long)
+
+                if is_gpu_runnable():
+                    batch = batch.cuda()
 
             h = self._readout(h, batch)
 
